//###########################################################################
// FILE:   Concerto_M3-Main.c



#include "Concerto_M3-Main.h"
#include "Serial_Cmd_Monitor.h"



#include <string.h>


#include "Task_Sheduler.h"

//*****************************************************************************
// Global vaiables
//*****************************************************************************


int32_t CycleCounter = 0;
int LEDPrescaleCount =0;


//*****************************************************************************
// Function Prototypes
//*****************************************************************************
void UART0Send(uint8_t *pucBuffer, int16_t usCount);

void UART0IntHandler(void);


void Timer0IntHandler(void);
void Timer1IntHandler(void);
void Timer2IntHandler(void);





#ifdef _FLASH
// These are defined by the linker (see device linker command file)
extern unsigned long RamfuncsLoadStart;
extern unsigned long RamfuncsRunStart;
extern unsigned long RamfuncsLoadSize;
#endif

//*****************************************************************************
// Data structure instances
//*****************************************************************************
       //


//*****************************************************************************
//
//! Main function
//!
//! Starting point for Concerto M3 core.
//!
//! \param None
//!
//! \return None.
//
//*****************************************************************************
int main(void)
{
//============================================
//	Local variables
//============================================

    uint32_t i = 0;

       // Allow writes to protected registers.
       HWREG(SYSCTL_MWRALLOW) = 0xA5A5A5A5;

       // Tasks State-machine init
       	State_Ptr = &ATaskState;
       	TimerFlags.Timer0 = 0;
       	TimerFlags.Timer1 = 0;
       	TimerFlags.Timer2 = 0;
//============================================
//	System Setup
//============================================

    // Sets up PLL, M3 running at 75MHz and C28 running at 150MHz
   // C28ClkIn clock is xtal (20) * SYSPLLMULT (15) / pll (2) / SYSCTL_SYSDIV_1 (1) = 150Mhz
   // M3Clk = C28ClkIn (150) / SYSCTL_M3SSDIV_2 (2) = 75Mhz
    SysCtlClockConfigSet(SYSCTL_USE_PLL | (SYSCTL_SPLLIMULT_M & 0xF) |
                         SYSCTL_SYSDIV_1 | SYSCTL_M3SSDIV_2 |
                         SYSCTL_XCLKDIV_4);

#ifdef _FLASH
// Copy time critical code and Flash setup code to RAM
// This includes the following functions:  InitFlash();
// The  RamfuncsLoadStart, RamfuncsLoadSize, and RamfuncsRunStart
// symbols are created by the linker. Refer to the device .cmd file.
    memcpy(&RamfuncsRunStart, &RamfuncsLoadStart, (size_t)&RamfuncsLoadSize);

// Call Flash Initialization to setup flash waitstates
// This function must reside in RAM
    FlashInit();
#endif


//--------------------------------------
//GPIO Setup
//--------------------------------------


    PinoutSet();


	GPIOPinWrite(LED_1_BASE, LED_1_PIN, 0);  //M3 LED on
//--------------------------------------
//Peripherals Enable
//--------------------------------------
    // Enable the peripherals used.
    SysCtlPeripheralEnable(SYSCTL_PERIPH_UART0);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_TIMER0);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_TIMER1);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_TIMER2);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_TIMER3);

    // Unlock the register to change the commit register value for Port B Pin 7
    // This disables the NMI functionality on the pin and allows other muxing
    // options to be used
    HWREG(GPIO_PORTB_BASE+GPIO_O_LOCK) = GPIO_LOCK_KEY_DD;
    // Write to commit register
    HWREG(GPIO_PORTB_BASE+GPIO_O_CR) |= 0x000000FF;
    // Delay
    for (i=0;i<20;i++){};


//     assign S0 and S1 of the shared ram for use by the c28
//     Details of how c28 uses these memory sections is defined
//     in the c28 linker file.(28M35H52C1_RAM_lnk.cmd)
//    RAMMReqSharedMemAccess((S0_ACCESS),SX_C28MASTER);



//--------------------------------------
//	Start C28
//--------------------------------------

	#ifdef _STANDALONE
	#ifdef _FLASH
		//  Send boot command to allow the C28 application to begin execution
		IPCMtoCBootControlSystem(CBROM_MTOC_BOOTMODE_BOOT_FROM_FLASH);
	#else
		//  Send boot command to allow the C28 application to begin execution
		IPCMtoCBootControlSystem(CBROM_MTOC_BOOTMODE_BOOT_FROM_RAM);
	#endif
	#endif
//--------------------------------------
//	Timer 0 Setup
//--------------------------------------
	// Configure the two 32-bit periodic timers.
	TimerConfigure(TIMER0_BASE, TIMER_CFG_32_BIT_PER);
 // TimerLoadSet(TIMER0_BASE, TIMER_A, SysCtlClockGet(SYSTEM_CLOCK_SPEED));
//    TimerLoadSet(TIMER0_BASE, TIMER_A, 1000/(0.01333333333) );// time in us
	TimerLoadSet(TIMER0_BASE, TIMER_A, 100/(0.01333333333) );// time in us

	// Setup the interrupts for the timer timeouts.
	IntEnable(INT_TIMER0A);
	TimerIntEnable(TIMER0_BASE, TIMER_TIMA_TIMEOUT);
	IntRegister(INT_TIMER0A, Timer0IntHandler);
	IntPrioritySet(INT_TIMER0A,0xC0);

	TimerEnable(TIMER0_BASE, TIMER_A);
//--------------------------------------
//Timer 1 Setup
//--------------------------------------
    // Configure the two 32-bit periodic timers.
    TimerConfigure(TIMER1_BASE, TIMER_CFG_32_BIT_PER);
    //TimerLoadSet(TIMER1_BASE, TIMER_A, SysCtlClockGet(SYSTEM_CLOCK_SPEED) / 2);
    TimerLoadSet(TIMER1_BASE, TIMER_A, 100000/(0.01333333333) ); //time in us

    // Setup the interrupts for the timer timeouts.
    IntEnable(INT_TIMER1A);
    TimerIntEnable(TIMER1_BASE, TIMER_TIMA_TIMEOUT);
    IntRegister(INT_TIMER1A, Timer1IntHandler);
    IntPrioritySet(INT_TIMER1A,0xB0);

    // Enable the timers.
    TimerEnable(TIMER1_BASE, TIMER_A);

//--------------------------------------
//Timer 2 Setup
//--------------------------------------
	// Configure the two 32-bit periodic timers.
	TimerConfigure(TIMER2_BASE, TIMER_CFG_32_BIT_PER);
	//TimerLoadSet(TIMER1_BASE, TIMER_A, SysCtlClockGet(SYSTEM_CLOCK_SPEED) / 2);
	TimerLoadSet(TIMER2_BASE, TIMER_A, 1000/(0.01333333333) );//time in us

	// Setup the interrupts for the timer timeouts.
	IntEnable(INT_TIMER2A);
	TimerIntEnable(TIMER2_BASE, TIMER_TIMA_TIMEOUT);
	IntRegister(INT_TIMER2A, Timer2IntHandler);
	IntPrioritySet(INT_TIMER2A,0xA0);

	// Enable the timers.
	TimerEnable(TIMER2_BASE, TIMER_A);





//--------------------------------------
//	UART0 Setup (WC comms)
//--------------------------------------
    // Configure the UART for 115,200, 8-N-1 operation.
    UARTConfigSetExpClk(UART0_BASE, SysCtlClockGet(SYSTEM_CLOCK_SPEED), 9600,
                        (UART_CONFIG_WLEN_8 | UART_CONFIG_STOP_ONE |
                         UART_CONFIG_PAR_NONE));

    // Enable the UART interrupt.
    IntRegister(INT_UART0, UART0IntHandler);
    IntEnable(INT_UART0);
    UARTIntEnable(UART0_BASE, UART_INT_RX | UART_INT_RT);
    IntPrioritySet(INT_UART0,0x80);

    UARTFIFOEnable(INT_UART0);
    UARTFIFOLevelSet(INT_UART0,UART_FIFO_TX4_8,UART_FIFO_RX1_8);

    //set UART's 485 Line Driver Direction
    GPIOPinWrite(UART0_485_DIR_BASE, UART0_485_DIR_PIN,0); //set to low (Recieve mode)



    //Enable processor interrupts.
    IntMasterEnable();
//    IntDisable(INT_GPIOQ);


//============================================
//	Main Loop
//============================================
    while(1) //infinite loop
    {

			// State machine entry & exit point
			//===========================================================
			(*State_Ptr)();	// jump to an Alpha state (A0,B0,...)
			//===========================================================


    }//while
}//mian







//#############################################################################
//	Functions
//#############################################################################



//*****************************************************************************
//
//! A - TASKS
//!
//! Main task loop. Tasks are executed every 100 usec. Function is called by the Task Scheduler.
//! Period controlled by Timer0 interrupt.
//!
//! \param None
//!
//! \return None.
//
//*****************************************************************************
//--------------------------------------------------------
void ATasks(void)
//--------------------------------------------------------
{

	int WordIndex = 0;
	CycleCounter++;


}




//*****************************************************************************
//
//! B - TASKS
//!
//! LED task loop. Tasks are executed every 100 msec. Function is called by the Task Scheduler.
//! Period controlled by Timer1 interrupt.
//! Handles the switching of LED's
//!
//! \param None
//!
//! \return None.
//
//*****************************************************************************
//----------------------------------------
void BTasks(void) // LED's
//----------------------------------------
{



	//--------------------------------------------------------
	//    	M3 LED control
	//--------------------------------------------------------

	GPIOPinWrite(LED_1_BASE, LED_1_PIN, ~0);//LED off every 100ms
	if (LEDPrescaleCount++ == 10)
	{
		GPIOPinWrite(LED_1_BASE, LED_1_PIN, 0); //LED on every 10*100ms
		LEDPrescaleCount = 0;
	}



}

//*****************************************************************************
//
//! C - TASKS
//!
//! System Healthy task loop. Tasks are executed every 1 msec. Function is called by the Task Scheduler.
//! Period controlled by Timer2 interrupt.
//! Handles all system health checks
//!
//! \param None
//!
//! \return None.
//
//*****************************************************************************

//----------------------------------------
void CTasks(void) 	// health flags check
//----------------------------------------
{




}





//*****************************************************************************
//
//! UART0 Send
//!
//! Sends a string (number of Bytes) to UART0
//!
//! \param pucBuffer Pointer to the first Byte that should be sent.
//! \param usCount Number of consecutive Bytes to send.
//!
//! \return None.
//
//*****************************************************************************
void UART0Send(uint8_t *pucBuffer, int16_t usCount)
{

    // Loop while there are more characters to send.
    while(usCount--)
    {
        // Write the next character to the UART.
        //UARTCharPutNonBlocking(UART0_BASE, *pucBuffer++);
    	UARTCharPut(UART0_BASE, *pucBuffer++);
    }
}






//#############################################################################
//	Interrupts
//#############################################################################


//*****************************************************************************
//
//! UART0 Interrupt
//!
//! Handles string (number of Bytes) received on UART0
//!
//! \param None
//!
//! \return None.
//
//*****************************************************************************
void UART0IntHandler(void)
{
    unsigned long ulStatus;

    // Get the interrupt status.
    ulStatus = UARTIntStatus(UART0_BASE, true);


	while( UARTCharsAvail(UART0_BASE) )
	{
		receivedDataCommand(UARTCharGetNonBlocking(UART0_BASE));
	}

//    if (ulStatus & UART_INT_RT) // check if timeout interrupt was activated showing end of package
//    {
//
//    }

    // Clear the asserted interrupts.
    UARTIntClear(UART0_BASE, ulStatus);
}




//*****************************************************************************
//
//! Timer0 Interrupt
//!
//! Handles Interrupt for timer 0
//!
//! \param None
//!
//! \return None.
//
//*****************************************************************************
void
Timer0IntHandler(void)
{
    // Clear the timer interrupt.
    TimerIntClear(TIMER0_BASE, TIMER_TIMA_TIMEOUT);

    //	Trigers the ATasks.
    TimerFlags.Timer0 = 1;


}

//*****************************************************************************
//
//! Timer1 Interrupt
//!
//! Handles Interrupt for timer 1
//!
//! \param None
//!
//! \return None.
//
//*****************************************************************************
void
Timer1IntHandler(void)
{
    // Clear the timer interrupt.
    TimerIntClear(TIMER1_BASE, TIMER_TIMA_TIMEOUT);

    TimerFlags.Timer1 = 1;
}


//*****************************************************************************
//
//! Timer2 Interrupt
//!
//! Handles Interrupt for timer 2
//!
//! \param None
//!
//! \return None.
//
//*****************************************************************************
void
Timer2IntHandler(void)
{
    // Clear the timer interrupt.
    TimerIntClear(TIMER2_BASE, TIMER_TIMA_TIMEOUT);

    TimerFlags.Timer2 = 1;
}

//*****************************************************************************
//
//! Timer3 Interrupt
//!
//! Handles Interrupt for timer 3
//!
//! \param None
//!
//! \return None.
//
//*****************************************************************************
void
Timer3IntHandler(void)
{
    // Clear the timer interrupt.
    TimerIntClear(TIMER3_BASE, TIMER_TIMA_TIMEOUT);

//    TimerFlags.Timer3 = 1;
    CycleCounter++;
}









//*****************************************************************************
//
// Close the Doxygen group.
//! @}
//
//*****************************************************************************
