//###########################################################################
// FILE:   set_pinout_f28m35x.c
// TITLE:  GPIO setup for the F28M35x controlCARD.
//###########################################################################
// $TI Release: F28M36x Support Library v207 $
// $Release Date: Mon Sep 21 16:44:39 CDT 2015 $
// $Copyright: Copyright (C) 2012-2015 Texas Instruments Incorporated -
//             http://www.ti.com/ ALL RIGHTS RESERVED $
//###########################################################################

#include "set_pinout.h"

#include "inc/hw_gpio.h"
#include "inc/hw_memmap.h"
#include "inc/hw_types.h"
#include "driverlib/debug.h"
#include "driverlib/epi.h"
#include "driverlib/gpio.h"
#include "driverlib/i2c.h"
#include "driverlib/rom.h"
#include "driverlib/sysctl.h"
//#include "board_drivers/set_pinout_f28m36x.h"


//*****************************************************************************
//
//! Set the GPIO port control registers appropriately for the hardware.
//!
//! This function determines the correct port control settings to enable the
//! basic peripheral signals for the development board on their respective pins
//! and also ensures that all required EPI signals are correctly routed.  The
//! EPI signal configuration is determined from the daughter board information
//! structure passed via the \e psInfo parameter.
//
//*****************************************************************************
static void
PortControlSet(void)
{
   
    //
    // To begin with, we set the port control values for all the non-EPI
    // peripherals.
    //

	//----------------------
    //UART pin Setup
	//----------------------
    // Set GPIO J2 and J3 as UART0 pins.
    GPIOPinConfigure(GPIO_PJ2_U0TX);
    GPIOPinConfigure(GPIO_PJ3_U0RX);
    GPIOPinTypeUART(GPIO_PORTJ_BASE, GPIO_PIN_2 | GPIO_PIN_3);





    //----------------------
    //Pullups
    //----------------------
    // Enable Pullups on EPWM(1-8)A/B capable pins
    GPIOPadConfigSet(GPIO_PORTA_BASE, 0xFF, GPIO_PIN_TYPE_STD_WPU);
    //GPIOPadConfigSet(GPIO_PORTB_BASE, 0xFF, GPIO_PIN_TYPE_STD_WPU);

    //----------------------
    //LED's
    //----------------------
    // Set up the Pin for M3 LED
    GPIOPinTypeGPIOOutput(LED_1_BASE, LED_1_PIN);
    GPIOPinTypeGPIOOutputHigh(LED_1_BASE, LED_1_PIN); //start with LED off, LED's are active low
//    GPIOPinWrite(LED_1_BASE, LED_1_PIN, 1);





    //set up pin for UART's 485 Line Driver Direction
    GPIOPinTypeGPIOOutput(UART0_485_DIR_BASE, UART0_485_DIR_PIN);
    GPIOPinTypeGPIOOutputLow(UART0_485_DIR_BASE, UART0_485_DIR_PIN); //set default to low (Recieve mode)


}

//*****************************************************************************
//
//! Configures the device pinout for the development board.
//!
//! This function configures each pin of the device to route the! appropriate
//! peripheral signal as required by the design of the development board.
//!
//! \note This module can be built in two ways.  If the label SIMPLE_PINOUT_SET
//! is not defined, the PinoutSet() function will attempt to read an I2C EEPROM
//! to determine which daughter board is attached to the development kit board
//! and use information from that EEPROM to dynamically configure the EPI
//! appropriately.  In this case, if no EEPROM is found, the EPI configuration
//! will default to that required to use the SDRAM daughter board which is
//! included with the base development kit.
//!
//! If SIMPLE_PINOUT_SET is defined, however, all the dynamic configuration
//! code is replaced with a very simple function which merely sets the pinout
//! and EPI configuration statically.  This is a better representation of how a
//! real-world application would likely initialize the pinout and EPI timing
//! and takes significantly less code space than the dynamic, daughter-board
//! detecting version.  The example offered here sets the pinout and EPI
//! configuration appropriately for the Flash/SRAM/LCD daughter board.
//!
//! \return None.
//
//*****************************************************************************
void
PinoutSet(void)
{
    
    //
    // Enable all GPIO banks.
    //
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOA);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOB);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOC);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOD);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOE);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOF);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOG);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOH);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOJ);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOK);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOL);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOM);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPION);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOP);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOQ);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOR);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOS);


    //
    // Determine the port control settings required to enable the EPI pins
    // and other peripheral signals for this daughter board and set all the
    // GPIO port control registers.
    //
    PinCoreSelect();
    PortControlSet();

}


//*****************************************************************************
//
//! Configures which core owns which pins.
//!
//!	This funcion groups all GPIO setup in one place to make transfer to other hardware easier.
//! \return None.
//
//*****************************************************************************
void PinCoreSelect()
{

//	// Give M3 control of all GPIOs
	GPIOPinConfigureCoreSelect(GPIO_PORTA_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);
	GPIOPinConfigureCoreSelect(GPIO_PORTB_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);
	GPIOPinConfigureCoreSelect(GPIO_PORTC_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);
	GPIOPinConfigureCoreSelect(GPIO_PORTD_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);
	GPIOPinConfigureCoreSelect(GPIO_PORTE_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);
	GPIOPinConfigureCoreSelect(GPIO_PORTF_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);
	GPIOPinConfigureCoreSelect(GPIO_PORTG_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);
	GPIOPinConfigureCoreSelect(GPIO_PORTH_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);
	GPIOPinConfigureCoreSelect(GPIO_PORTJ_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);
	GPIOPinConfigureCoreSelect(GPIO_PORTK_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);
	GPIOPinConfigureCoreSelect(GPIO_PORTL_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);
	GPIOPinConfigureCoreSelect(GPIO_PORTM_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);
	GPIOPinConfigureCoreSelect(GPIO_PORTN_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);
	GPIOPinConfigureCoreSelect(GPIO_PORTP_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);
	GPIOPinConfigureCoreSelect(GPIO_PORTQ_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);
	GPIOPinConfigureCoreSelect(GPIO_PORTR_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);
	GPIOPinConfigureCoreSelect(GPIO_PORTS_BASE, 0xFF, GPIO_PIN_M_CORE_SELECT);




}




//*****************************************************************************
//
// Close the Doxygen group.
//! @}
//
//*****************************************************************************
